aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java
diff options
context:
space:
mode:
authorGravatar David Chen <dzc@google.com>2016-05-19 22:01:19 +0000
committerGravatar Kristina Chodorow <kchodorow@google.com>2016-05-20 14:41:16 +0000
commitf62db46b49fb2016ca4dad300374ddbbe5ffee43 (patch)
treee08948a5848e719129c99824a5e2c9fa82d979cd /src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java
parent35c1aa8cdd6057acdc0e7035ec766f616052c127 (diff)
Update Bazel native rule documentation to use new ${link} syntax.
-- MOS_MIGRATED_REVID=122772973
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java b/src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java
index b6de01ba35..bba3222850 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/android/AndroidBinaryOnlyRule.java
@@ -54,7 +54,7 @@ public final class AndroidBinaryOnlyRule implements RuleDefinition {
// higher number.
// This overrides the value declared in the manifest.
//
// Subject to <a href="make-variables.html">"Make" variable</a> substitution.
// Suggested practice is to declare a varrdef and reference it here so that a particular build
// invocation will be used to generate apks for release.
// <!-- #END_BLAZE_RULE.ATTRIBUTE --> */
@@ -64,7 +64,7 @@ public final class AndroidBinaryOnlyRule implements RuleDefinition {
// users. The version_code attribute holds the significant version number used internally.
// This overrides the value declared in the manifest.
//
// Subject to <a href="make-variables.html">"Make" variable</a> substitution.
// Suggested practice is to declare a varrdef and reference it here so that a particular build
// invocation will be used to generate apks for release.
// <!-- #END_BLAZE_RULE.ATTRIBUTE --> */
@@ -120,7 +120,7 @@ public final class AndroidBinaryOnlyRule implements RuleDefinition {
<li><code>manual_main_dex</code>: Split code into multiple dex files when the
dex 64K index limit is exceeded. The content of the main dex file
needs to be specified by providing a list of classes in a text file
- using the <a href="#android_binary.main_dex_list">main_dex_list</a>.</li>
+ using the <a href="${link android_binary.main_dex_list}">main_dex_list</a>.</li>
<li><code>off</code>: Compile all code to a single dex file, even if
if exceeds the index limit.</li>
</ul>
@@ -54,7 +54,7 @@ public final class AndroidBinaryOnlyRule implements RuleDefinition {
// This overrides the value declared in the manifest.
//
-// Subject to <a href="make-variables.html">"Make" variable</a> substitution.
+// Subject to <a href="${link make-variables}">"Make" variable</a> substitution.
// Suggested practice is to declare a varrdef and reference it here so that a particular build
// invocation will be used to generate apks for release.
@@ -64,7 +64,7 @@ public final class AndroidBinaryOnlyRule implements RuleDefinition {
// This overrides the value declared in the manifest.
//
-// Subject to <a href="make-variables.html">"Make" variable</a> substitution.
+// Subject to <a href="${link make-variables}">"Make" variable</a> substitution.
// Suggested practice is to declare a varrdef and reference it here so that a particular build
// invocation will be used to generate apks for release.